﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Data;
using HeuristicLab.Parameters;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.SimulationCore.Samples {
  [Item("GameOfLifeScenario", "A game of life scenario.")]
  [StorableClass]
  public sealed class GameOfLifeScenario : Scenario {
    public IFixedValueParameter<IntValue> WidthParameter {
      get { return (IFixedValueParameter<IntValue>)Parameters["Width"]; }
    }
    public IFixedValueParameter<IntValue> HeightParameter {
      get { return (IFixedValueParameter<IntValue>)Parameters["Height"]; }
    }
    public IFixedValueParameter<PercentValue> AliveRateParameter {
      get { return (IFixedValueParameter<PercentValue>)Parameters["AliveRate"]; }
    }

    public GameOfLifeScenario()
      : base() {
      Parameters.Add(new FixedValueParameter<IntValue>("Width", "The width value.", new IntValue(100)));
      Parameters.Add(new FixedValueParameter<IntValue>("Height", "The height value.", new IntValue(100)));
      Parameters.Add(new FixedValueParameter<PercentValue>("AliveRate", "The rate of the initialyy alive cells.", new PercentValue(0.5)));
    }
    [StorableConstructor]
    private GameOfLifeScenario(bool deserializing) : base(deserializing) { }
    private GameOfLifeScenario(GameOfLifeScenario original, Cloner cloner)
      : base(original, cloner) {
    }
    public override IDeepCloneable Clone(Cloner cloner) {
      return new GameOfLifeScenario(this, cloner);
    }
  }
}
